@@ -51,12 +51,18 @@ SERVICE_VERSIONS = {
     "cbs": [
         "2017-03-12"
     ],
+    "ccc": [
+        "2020-02-10"
+    ],
     "cdb": [
         "2017-03-20"
     ],
     "cdn": [
         "2018-06-06"
     ],
+    "cdwdoris": [
+        "2021-12-28"
+    ],
     "cfs": [
         "2019-07-19"
     ],
@@ -213,6 +219,9 @@ SERVICE_VERSIONS = {
     "ocr": [
         "2018-11-19"
     ],
+    "omics": [
+        "2022-11-28"
+    ],
     "organization": [
         "2021-03-31",
         "2018-12-25"
@@ -311,6 +320,9 @@ SERVICE_VERSIONS = {
     "vpc": [
         "2017-03-12"
     ],
+    "wedata": [
+        "2021-08-20"
+    ],
     "yunjing": [
         "2018-02-28"
     ]
